package com.ruoyi.custclient.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.custclient.domain.CustInfo;
import com.ruoyi.custclient.service.ICustInfoService;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.page.TableDataInfo;

/**
 * 客户信息Controller
 * 
 * @author wuyufei
 * @date 2024-10-21
 */
@RestController
@RequestMapping("/info")
public class CustInfoController extends BaseController
{
    @Autowired
    private ICustInfoService custInfoService;

    /**
     * 查询客户信息列表
     */
    @RequiresPermissions("custclient:info:list")
    @GetMapping("/list")
    public TableDataInfo list(CustInfo custInfo)
    {
        startPage();
        List<CustInfo> list = custInfoService.selectCustInfoList(custInfo);
        return getDataTable(list);
    }

    /**
     * 导出客户信息列表
     */
    @RequiresPermissions("custclient:info:export")
    @Log(title = "客户信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CustInfo custInfo)
    {
        List<CustInfo> list = custInfoService.selectCustInfoList(custInfo);
        ExcelUtil<CustInfo> util = new ExcelUtil<CustInfo>(CustInfo.class);
        util.exportExcel(response, list, "客户信息数据");
    }

    /**
     * 获取客户信息详细信息
     */
    @RequiresPermissions("custclient:info:query")
    @GetMapping(value = "/{custId}")
    public AjaxResult getInfo(@PathVariable("custId") Long custId)
    {
        return success(custInfoService.selectCustInfoByCustId(custId));
    }

    /**
     * 新增客户信息
     */
    @RequiresPermissions("custclient:info:add")
    @Log(title = "客户信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CustInfo custInfo)
    {
        return toAjax(custInfoService.insertCustInfo(custInfo));
    }

    /**
     * 修改客户信息
     */
    @RequiresPermissions("custclient:info:edit")
    @Log(title = "客户信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CustInfo custInfo)
    {
        return toAjax(custInfoService.updateCustInfo(custInfo));
    }

    /**
     * 删除客户信息
     */
    @RequiresPermissions("custclient:info:remove")
    @Log(title = "客户信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{custIds}")
    public AjaxResult remove(@PathVariable Long[] custIds)
    {
        return toAjax(custInfoService.deleteCustInfoByCustIds(custIds));
    }
}
