package com.ruoyi.custclient.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.custclient.service.ILabelTypeService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.system.domain.LabelType;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.page.TableDataInfo;

/**
 * 标签组Controller
 * 
 * @author ruoyi
 * @date 2024-10-17
 */
@RestController
@RequestMapping("/type")
public class LabelTypeController extends BaseController
{
    @Autowired
    private ILabelTypeService labelTypeService;

    /**
     * 查询标签组列表
     */
    @RequiresPermissions("system:type:list")
    @GetMapping("/list")
    public TableDataInfo list(LabelType labelType)
    {
        startPage();
        List<LabelType> list = labelTypeService.selectLabelTypeList(labelType);
        return getDataTable(list);
    }

    /**
     * 导出标签组列表
     */
    @RequiresPermissions("system:type:export")
    @Log(title = "标签组", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, LabelType labelType)
    {
        List<LabelType> list = labelTypeService.selectLabelTypeList(labelType);
        ExcelUtil<LabelType> util = new ExcelUtil<LabelType>(LabelType.class);
        util.exportExcel(response, list, "标签组数据");
    }

    /**
     * 获取标签组详细信息
     */
    @RequiresPermissions("system:type:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(labelTypeService.selectLabelTypeById(id));
    }

    /**
     * 新增标签组
     */
    @RequiresPermissions("system:type:add")
    @Log(title = "标签组", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody LabelType labelType)
    {
        return toAjax(labelTypeService.insertLabelType(labelType));
    }

    /**
     * 修改标签组
     */
    @RequiresPermissions("system:type:edit")
    @Log(title = "标签组", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody LabelType labelType)
    {
        return toAjax(labelTypeService.updateLabelType(labelType));
    }

    /**
     * 删除标签组
     */
    @RequiresPermissions("system:type:remove")
    @Log(title = "标签组", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(labelTypeService.deleteLabelTypeByIds(ids));
    }
}
