package com.ruoyi.custclient.service.impl;

import java.util.List;
import com.ruoyi.common.core.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.custclient.mapper.CustInfoMapper;
import com.ruoyi.custclient.domain.CustInfo;
import com.ruoyi.custclient.service.ICustInfoService;

/**
 * 客户信息Service业务层处理
 * 
 * @author wuyufei
 * @date 2024-10-21
 */
@Service
public class CustInfoServiceImpl implements ICustInfoService 
{
    @Autowired
    private CustInfoMapper custInfoMapper;

    /**
     * 查询客户信息
     * 
     * @param custId 客户信息主键
     * @return 客户信息
     */
    @Override
    public CustInfo selectCustInfoByCustId(Long custId)
    {
        return custInfoMapper.selectCustInfoByCustId(custId);
    }

    /**
     * 查询客户信息列表
     * 
     * @param custInfo 客户信息
     * @return 客户信息
     */
    @Override
    public List<CustInfo> selectCustInfoList(CustInfo custInfo)
    {
        return custInfoMapper.selectCustInfoList(custInfo);
    }

    /**
     * 新增客户信息
     * 
     * @param custInfo 客户信息
     * @return 结果
     */
    @Override
    public int insertCustInfo(CustInfo custInfo)
    {
        custInfo.setCreateTime(DateUtils.getNowDate());
        return custInfoMapper.insertCustInfo(custInfo);
    }

    /**
     * 修改客户信息
     * 
     * @param custInfo 客户信息
     * @return 结果
     */
    @Override
    public int updateCustInfo(CustInfo custInfo)
    {
        return custInfoMapper.updateCustInfo(custInfo);
    }

    /**
     * 批量删除客户信息
     * 
     * @param custIds 需要删除的客户信息主键
     * @return 结果
     */
    @Override
    public int deleteCustInfoByCustIds(Long[] custIds)
    {
        return custInfoMapper.deleteCustInfoByCustIds(custIds);
    }

    /**
     * 删除客户信息信息
     * 
     * @param custId 客户信息主键
     * @return 结果
     */
    @Override
    public int deleteCustInfoByCustId(Long custId)
    {
        return custInfoMapper.deleteCustInfoByCustId(custId);
    }
}
